@@ -1,5 +1,6 @@
 CREATE TABLE library (
 	id INTEGER NOT NULL PRIMARY KEY,
 	book TEXT NOT NULL,
-	isbn VARHCAR(13) NOT NULL UNIQUE
+	isbn VARHCAR(13) NOT NULL UNIQUE,
+	full_isbn VARHCAR(16) UNIQUE
 );
